@@ -35,6 +35,8 @@ from .models import (
     Point,
     Position,
     PositionMode,
+    RedactResponse,
+    RedactTarget,
     ShapeType,
     StandardFonts,
     TextObjectRef,
@@ -78,6 +80,8 @@ __all__ = [
     "Line",
     "Bezier",
     "Path",
+    "RedactTarget",
+    "RedactResponse",
     "PdfDancerException",
     "FontNotFoundException",
     "ValidationException",
